==> kbibtex-0.1.1.tar.bz2: kbibtex-0.1.1/src/bibtexfileparser.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXFILEPARSER_H
#define BIBTEXFILEPARSER_H

#include <qobject.h>

class BibTeXElement;

class BibTeXFileParser: public QObject
{
    Q_OBJECT

public:
    BibTeXFileParser( QTextStream *inputStream );

    BibTeXElement *nextElement();

public slots:
    void cancel();

signals:
    void progress( int current, int total );

private:
    enum Token {tComment, tPreamble, tBraketOpen, tBraketClose, tAlphaNumText, tComma, tSemicolon, tAssign, tString, tStrConcat, tUnknown, tEOF, tEntry};
    enum StringTerminator {stQuotationMark, stParenthesis, stCurlyBracket, stWhiteSpace};

    Token token;
    bool cancelFlag;
    QTextStream *stream;
    QString tokenBuffer;
    QChar tokenChar;

    Token readToken( );
    QString readChars( );
    BibTeXString* readString( );
    BibTeXEntry* readEntry( QString &entryType );
};

#endif

==> kbibtex-0.1.2.tar.bz2: kbibtex-0.1.2/src/bibtexfileparser.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXFILEPARSER_H
#define BIBTEXFILEPARSER_H

#include <qobject.h>

class BibTeXElement;

class BibTeXFileParser: public QObject
{
    Q_OBJECT

public:
    BibTeXFileParser( QTextStream *inputStream );

    BibTeXElement *nextElement();

public slots:
    void cancel();

signals:
    void progress( int current, int total );

private:
    enum Token {tComment, tPreamble, tBraketOpen, tBraketClose, tAlphaNumText, tComma, tSemicolon, tAssign, tString, tStrConcat, tUnknown, tEOF, tEntry};
    enum StringTerminator {stQuotationMark, stParenthesis, stCurlyBracket, stWhiteSpace};

    Token token;
    bool cancelFlag;
    QTextStream *stream;
    QString tokenBuffer;
    QChar tokenChar;

    Token readToken( );
    QString readChars( StringTerminator& stringTerminator );
    BibTeXString* readString( );
    BibTeXEntry* readEntry( QString &entryType );
};

#endif
